# TwoTruthsAndATwist
Two Truths and a Twist: The world's first Model Context Protocol game

[Game design document](https://docs.google.com/document/d/1kW88UU5bjszQJgyB_JNkpvbnfaSNcKIP4mRR3R-HL1o/edit?usp=sharing)
